changeset 64590:d098d958b288

(dired-move-to-filename-regexp): Recognize the B suffix of the file size (as in "177B" for 177 bytes). This happens with "ls -lh" on FreeBSD.
author Eli Zaretskii <eliz@gnu.org>
date Fri, 22 Jul 2005 09:54:45 +0000
parents 722ca9969d93
children c502137f8bb7
files lisp/dired.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/dired.el	Fri Jul 22 08:22:41 2005 +0000
+++ b/lisp/dired.el	Fri Jul 22 09:54:45 2005 +0000
@@ -1865,11 +1865,11 @@
 	 ;; The "[0-9]" below requires the previous column to end in a digit.
 	 ;; This avoids recognizing `1 may 1997' as a date in the line:
 	 ;; -r--r--r--   1 may      1997        1168 Oct 19 16:49 README
 	 ;; The "[kKMGTPEZY]?" below supports "ls -alh" output.
 	 ;; The ".*" below finds the last match if there are multiple matches.
 	 ;; This avoids recognizing `jservice  10  1024' as a date in the line:
 	 ;; drwxr-xr-x  3 jservice  10  1024 Jul  2  1997 esg-host
-    (concat ".*[0-9][kKMGTPEZY]?" s
+    (concat ".*[0-9][BkKMGTPEZY]?" s
 	    "\\(" western "\\|" western-comma "\\|" japanese "\\|" iso "\\)"
 	    s "+"))
   "Regular expression to match up to the file name in a directory listing.
@@ -1865,11 +1865,11 @@
 	 ;; This avoids recognizing `1 may 1997' as a date in the line:
 	 ;; -r--r--r--   1 may      1997        1168 Oct 19 16:49 README
-	 ;; The "[kKMGTPEZY]?" below supports "ls -alh" output.
+	 ;; The "[BkKMGTPEZY]?" below supports "ls -alh" output.
 	 ;; The ".*" below finds the last match if there are multiple matches.
 	 ;; This avoids recognizing `jservice  10  1024' as a date in the line: